# Dependents stats for dermatologist/pyomop

[![Generated by github-dependents-info](https://img.shields.io/static/v1?label=Used%20by&message=2&color=informational&logo=slickpic)](https://github.com/dermatologist/pyomop/network/dependents)
[![Generated by github-dependents-info](https://img.shields.io/static/v1?label=Used%20by%20(public)&message=2&color=informational&logo=slickpic)](https://github.com/dermatologist/pyomop/network/dependents)
[![Generated by github-dependents-info](https://img.shields.io/static/v1?label=Used%20by%20(private)&message=-2&color=informational&logo=slickpic)](https://github.com/dermatologist/pyomop/network/dependents)
[![Generated by github-dependents-info](https://img.shields.io/static/v1?label=Used%20by%20(stars)&message=8&color=informational&logo=slickpic)](https://github.com/dermatologist/pyomop/network/dependents)

| Repository | Stars  |
| :--------  | -----: |
|<img class="avatar mr-2" src="https://avatars.githubusercontent.com/u/11805788?s=40&v=4" width="20" height="20" alt="">  &nbsp; [alphavector](https://github.com/alphavector) / [all](https://github.com/alphavector/all) | 5 |
|<img class="avatar mr-2" src="https://avatars.githubusercontent.com/u/25952589?s=40&v=4" width="20" height="20" alt="">  &nbsp; [Lyn4ever29](https://github.com/Lyn4ever29) / [pipy_server](https://github.com/Lyn4ever29/pipy_server) | 3 |

_Generated using [github-dependents-info](https://github.com/nvuillam/github-dependents-info), by [Nicolas Vuillamy](https://github.com/nvuillam)_